PAWpySeed: /home/kyle/Research/projects/pawpyseed/pawpyseed/core/linalg.h Source File

PAWpySeed Parallel C/Python package for numerical analysis of PAW DFT wavefunctions

- Main Page
- Classes
- Files

- File List
- File Members

linalg.h
Go to the documentation of this file.
1
5 #ifndef FFT_H
6 #define FFT_H
7 #include <mkl.h>
8 #include <mkl_types.h>
9
16 void fft3d(double complex* x, int* G_bounds, double* lattice,
17 double* kpt, int* Gs, float complex* Cs, int num_waves, int* fftg);
18
19 void fwd_fft3d(double complex* x, int* G_bounds, double* lattice,
20 double* kpt, int* Gs, float complex* Cs, int num_waves, int* fftg);
21
22 #endif
pawpyseed.core.quadrature.x
list x
Definition: quadrature.py:9
fwd_fft3d
void fwd_fft3d(double complex *x, int *G_bounds, double *lattice, double *kpt, int *Gs, float complex *Cs, int num_waves, int *fftg)
fft3d
void fft3d(double complex *x, int *G_bounds, double *lattice, double *kpt, int *Gs, float complex *Cs, int num_waves, int *fftg)